PaperSize enum

Inheritance
Available extensions

Values

mm58 → const PaperSize
const PaperSize(width: 384, maxChars: 32, maxCharsCompressed: 42)
mm72 → const PaperSize
const PaperSize(width: 512, maxChars: 42, maxCharsCompressed: 56)
mm80 → const PaperSize
const PaperSize(width: 576, maxChars: 48, maxCharsCompressed: 64)
mm110 → const PaperSize
const PaperSize(width: 832, maxChars: 69, maxCharsCompressed: 92)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
maxChars → int
final
maxCharsCompressed → int
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
final

Methods

getMaxChars(FontSize fontSize) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PaperSize>
A constant List of the values in this enum, in order of their declaration.